@@ -1,17 +1,15 @@
 #%%
 from pathlib import Path
-from typing import Optional
+from typing import Optional, Union
 
 import typer
+from rich import print
 
 from metaDMG.cli import cli_utils
 
 
 cli_app = cli_utils.get_cli_app()
 
-output_dir_default = Path("./data/")
-results_dir_default = output_dir_default / "results"
-config_file_default = Path("config.yaml")
 
 #%%
 
@@ -58,58 +56,69 @@ def create_config(
         exists=True,
         file_okay=True,
         help="Path to the (NCBI) names-mdmg.dmp.",
+        rich_help_panel="LCA parameters",
     ),
     nodes: Optional[Path] = typer.Option(
         None,
         exists=True,
         file_okay=True,
         help="Path to the (NCBI) nodes-mdmg.dmp.",
+        rich_help_panel="LCA parameters",
     ),
     acc2tax: Optional[Path] = typer.Option(
         None,
         exists=True,
         file_okay=True,
         help="Path to the (NCBI) acc2tax.gz.",
+        rich_help_panel="LCA parameters",
     ),
-    min_similarity_score: float = typer.Option(
-        0.95,
+    min_similarity_score: Optional[float] = typer.Option(
+        None,
         "--min-similarity-score",
         "-s",
         help="Normalised edit distance (read to reference similarity) minimum. Number between 0-1.",
-        callback=lambda x: cli_utils.is_in_range(x, 0, 1),
+        callback=lambda x: cli_utils.is_in_range_or_None(x, 0, 1),
+        rich_help_panel="LCA parameters",
     ),
-    max_similarity_score: float = typer.Option(
-        1.0,
+    max_similarity_score: Optional[float] = typer.Option(
+        None,
         "--max-similarity-score",
         "-S",
         help="Normalised edit distance (read to reference similarity) maximum. Number between 0-1.",
-        callback=lambda x: cli_utils.is_in_range(x, 0, 1),
+        callback=lambda x: cli_utils.is_in_range_or_None(x, 0, 1),
+        rich_help_panel="LCA parameters",
     ),
-    min_edit_dist: int = typer.Option(
-        0,
+    min_edit_dist: Optional[int] = typer.Option(
+        None,
+        # 0,
         "--min-edit-dist",
         "-e",
-        help="Minimum edit distance (read to reference similarity). Number between 0-10.",
-        callback=lambda x: cli_utils.is_in_range(x, 0, 10),
+        help="Minimum edit distance (read to reference similarity). Positive integer.",
+        callback=lambda x: cli_utils.is_positive_int_or_None(x),
+        rich_help_panel="LCA parameters",
     ),
-    max_edit_dist: int = typer.Option(
-        10,
+    max_edit_dist: Optional[int] = typer.Option(
+        None,
+        # 10,
         "--max-edit-dist",
         "-E",
-        help="Maximum edit distance (read to reference similarity). Number between 0-10.",
-        callback=lambda x: cli_utils.is_in_range(x, 0, 10),
+        help="Maximum edit distance (read to reference similarity). Positive integer.",
+        callback=lambda x: cli_utils.is_positive_int_or_None(x),
+        rich_help_panel="LCA parameters",
     ),
     min_mapping_quality: int = typer.Option(
         0,
         "--min-mapping-quality",
         "-q",
         help="Minimum mapping quality.",
+        rich_help_panel="LCA parameters",
     ),
     custom_database: bool = typer.Option(
         False,
         "--custom-database",
         "-u",
         help="Fix the (ncbi) database. Disable if using a custom database.",
+        rich_help_panel="LCA parameters",
     ),
     lca_rank: cli_utils.RANKS = typer.Option(
         cli_utils.RANKS.none,
@@ -117,6 +126,7 @@ def create_config(
         "-r",
         case_sensitive=False,
         help="The LCA rank used in ngsLCA.",
+        rich_help_panel="LCA parameters",
     ),
     # GENERAL PARAMETERS
     metaDMG_cpp: str = typer.Option(
@@ -124,67 +134,86 @@ def create_config(
         "--metaDMG-cpp",
         "-m",
         help="The command needed to run the metaDMG-cpp program.",
+        rich_help_panel="General parameters",
     ),
     max_position: int = typer.Option(
         15,
         "--max-position",
         "-P",
         help="Number of positions to include (|x| < max_position).",
+        rich_help_panel="General parameters",
+    ),
+    min_reads: int = typer.Option(
+        0,
+        "--min-reads",
+        "-n",
+        help="Minimum number of reads to include in the fits (min_reads <= N_reads).",
+        rich_help_panel="General parameters",
     ),
     weight_type: int = typer.Option(
         1,
         "--weight-type",
         "-w",
         help="Method for calculating weights",
+        rich_help_panel="General parameters",
     ),
     forward_only: bool = typer.Option(
         False,
         "--forward-only",
         "-l",
         help="Only use the forward direction.",
+        rich_help_panel="General parameters",
     ),
     bayesian: bool = typer.Option(
         False,
         "--bayesian",
         "-b",
         help="Include a fully Bayesian model (probably better, but also _a lot_ slower, about a factor of 100.",
+        rich_help_panel="General parameters",
     ),
     output_dir: Path = typer.Option(
-        output_dir_default,
+        cli_utils.output_dir_default,
         "--output-dir",
         "-o",
         help="Path where the generated output files and folders are stored.",
+        rich_help_panel="General parameters",
     ),
     parallel_samples: int = typer.Option(
         1,
         "--parallel-samples",
         "-j",
         help="The number of samples to run in parallel. Default is running in seriel.",
+        rich_help_panel="General parameters",
     ),
     cores_per_sample: int = typer.Option(
         1,
         "--cores-per-sample",
         "-i",
         help="Number of cores to use pr. sample. ",
+        rich_help_panel="General parameters",
     ),
     config_file: Path = typer.Option(
-        config_file_default,
+        cli_utils.config_file_default,
         "--config-file",
         "-c",
         help="The name of the config file. ",
+        rich_help_panel="General parameters",
     ),
     sample_prefix: str = typer.Option(
         "",
         help="Prefix for the sample names.",
+        rich_help_panel="General parameters",
     ),
     sample_suffix: str = typer.Option(
         "",
         help="Suffix for the sample names.",
+        rich_help_panel="General parameters",
     ),
     long_name: bool = typer.Option(
         False,
         "--long-name",
         help="Use the full name of the sample file as sample name..",
+        rich_help_panel="General parameters",
     ),
     damage_mode: cli_utils.DAMAGE_MODE = typer.Option(
         cli_utils.DAMAGE_MODE.LCA,
@@ -192,12 +221,14 @@ def create_config(
         "-d",
         case_sensitive=False,
         help="The Damage Mode. Use 'LCA' unless you know what you are doing.",
+        rich_help_panel="General parameters",
     ),
     overwrite_config: bool = typer.Option(
         False,
         "--overwrite",
         "-f",
         help="Overwrite config file without user confirmation.",
+        rich_help_panel="General parameters",
     ),
 ):
     """Generate the config file."""
@@ -205,46 +236,59 @@ def create_config(
     if (damage_mode.lower() == "lca") and (
         any(x is None for x in [names, nodes, acc2tax])
     ):
-        typer.echo("--names, --nodes, and --acc2tax are mandatory when doing LCA.")
+        print(
+            "[red]--names[/red], [red]--nodes[/red], and [red]--acc2tax[/red] "
+            "are mandatory when doing LCA. \n"
+            "If you do not want to perform LCA, set [green]--damage-mode[/green] "
+            "to [green]LOCAL[/green] or [green]GLOBAL[/green]."
+        )
         raise typer.Exit(code=1)
 
-    from metaDMG import __version__, utils
+    from metaDMG import __version__
 
-    config = utils.paths_to_strings(
-        {
-            "samples": utils.extract_samples(
-                samples,
-                prefix=sample_prefix,
-                suffix=sample_suffix,
-                long_name=long_name,
-            ),
-            #
-            "metaDMG_cpp": metaDMG_cpp,
-            "names": names,
-            "nodes": nodes,
-            "acc2tax": acc2tax,
-            "min_similarity_score": min_similarity_score,
-            "max_similarity_score": max_similarity_score,
-            "min_edit_dist": min_edit_dist,
-            "max_edit_dist": max_edit_dist,
-            "min_mapping_quality": min_mapping_quality,
-            "lca_rank": lca_rank.value,  # important to get string
-            "max_position": max_position,
-            "weight_type": weight_type,
-            "custom_database": custom_database,
-            "forward_only": forward_only,
-            #
-            "output_dir": output_dir,
-            "parallel_samples": parallel_samples,
-            "cores_per_sample": cores_per_sample,
-            "bayesian": bayesian,
-            "config_file": str(config_file),
-            "damage_mode": damage_mode.lower(),
-            "version": __version__,
-        }
+    config = cli_utils.get_config_dict(
+        samples=samples,
+        names=names,
+        nodes=nodes,
+        acc2tax=acc2tax,
+        min_similarity_score=min_similarity_score,
+        max_similarity_score=max_similarity_score,
+        min_edit_dist=min_edit_dist,
+        max_edit_dist=max_edit_dist,
+        min_mapping_quality=min_mapping_quality,
+        custom_database=custom_database,
+        lca_rank=lca_rank,
+        metaDMG_cpp=metaDMG_cpp,
+        max_position=max_position,
+        min_reads=min_reads,
+        weight_type=weight_type,
+        forward_only=forward_only,
+        bayesian=bayesian,
+        output_dir=output_dir,
+        parallel_samples=parallel_samples,
+        cores_per_sample=cores_per_sample,
+        config_file=config_file,
+        sample_prefix=sample_prefix,
+        sample_suffix=sample_suffix,
+        long_name=long_name,
+        damage_mode=damage_mode,
+        __version__=__version__,
     )
 
-    utils.save_config_file(config, config_file, overwrite_config)
+    cli_utils.save_config_file(config, config_file, overwrite_config)
+
+
+#%%
+
+
+@cli_app.command("config-gui")
+def create_config_gui():
+    """Generate the config file via a simple GUI."""
+
+    from metaDMG.cli import cli_gui
+
+    gui = cli_gui.Gui(verbose=True)
+    gui.mainloop()
 
 
 #%%
@@ -362,7 +406,7 @@ def dashboard(
 #%%
 
 
-@cli_app.command("convert")
+@cli_app.command("convert", rich_help_panel="Utils")
 def convert(
     config_file: Optional[Path] = typer.Argument(
         None,
@@ -404,7 +448,7 @@ def convert(
 #%%
 
 
-@cli_app.command("filter")
+@cli_app.command("filter", rich_help_panel="Utils")
 def filter(
     config_file: Optional[Path] = typer.Argument(
         None,
@@ -452,7 +496,7 @@ def filter(
 #%%
 
 
-@cli_app.command("plot")
+@cli_app.command("plot", rich_help_panel="Utils")
 def plot(
     config_file: Optional[Path] = typer.Argument(
         None,
@@ -525,7 +569,7 @@ def plot(
 #%%
 
 
-@cli_app.command("get-data")
+@cli_app.command("get-data", rich_help_panel="Utils")
 def get_data(
     output_dir: Path = typer.Option(
         ...,
@@ -544,7 +588,7 @@ def get_data(
 #%%
 
 
-@cli_app.command("mismatch-to-mapDamage")
+@cli_app.command("mismatch-to-mapDamage", rich_help_panel="Utils")
 def mismatch_to_mapDamage(
     filename: Path = typer.Argument(
         ...,
@@ -573,21 +617,35 @@ def mismatch_to_mapDamage(
 #%%
 
 
-@cli_app.command("PMD")
-def compute_PMD(
-    config_file: Path = typer.Argument(
+@cli_app.command("PMD", rich_help_panel="Utils")
+def PMD(
+    filename: Path = typer.Argument(
         ...,
         file_okay=True,
-        help="Path to the config-file.",
+        help="Path to the config-file or a single BAM file.",
+    ),
+    csv_out: Path = typer.Option(
+        ...,
+        "--output",
+        "-o",
+        file_okay=True,
+        help="Output CSV file.",
+    ),
+    metaDMG_cpp: str = typer.Option(
+        "./metaDMG-cpp",
+        "--metaDMG-cpp",
+        "-m",
+        help="The command needed to run the metaDMG-cpp program.",
     ),
 ):
-    """Compute the PMD scores for the samples in the config file."""
+    """Compute the PMD scores for the chosen BAM file and save to csv."""
 
-    from metaDMG.utils import make_configs, run_PMD
+    from metaDMG.PMD import compute_PMDs
 
-    configs = make_configs(config_file)
-    for config in configs:
-        run_PMD(config)
+    df_PMDs = compute_PMDs(filename, metaDMG_cpp)
+
+    csv_out.parent.mkdir(parents=True, exist_ok=True)
+    df_PMDs.to_csv(csv_out, index=False)
 
 
 #%%
