@@ -169,6 +169,7 @@ def make_configs(
     d.setdefault("forward_only", False)
     d.setdefault("cores_per_sample", 1)
     d.setdefault("damage_mode", "lca")
+    d.setdefault("min_reads", 0)
     d["force"] = force
 
     paths = ["names", "nodes", "acc2tax", "output_dir", "config_file"]
@@ -279,199 +280,9 @@ def split_string(s: str) -> list[str]:
 #%%
 
 
-def path_endswith(path: Path, s: str) -> bool:
-    return str(path.name).endswith(s)
-
-
-def extract_name(
-    filename: Path,
-    max_length: int = 100,
-    prefix: str = "",
-    suffix: str = "",
-    long_name: bool = False,
-) -> str:
-    """Extract the name from a file
-
-    Parameters
-    ----------
-    filename
-        The input file
-    max_length
-        The maximum length of the name, by default 100
-    prefix
-        The prefix to be added to the name, by default ""
-    suffix
-        The suffix to be added to the name, by default ""
-    long_name
-        Whether or not to use the full name, by default False
-
-    Returns
-    -------
-        The name
-    """
-    name = Path(filename).stem
-    if not long_name:
-        name = name.split(".")[0]
-    if len(name) > max_length:
-        name = name[:max_length] + "..."
-    name = prefix + name + suffix
-    return name
-
-
-def extract_names(file_list, **kwargs):
-    return list(map(partial(extract_name, **kwargs), file_list))
-
-
-def extract_alignment_files(paths: list[Path]) -> list[Path]:
-    """Extract all alignment files from a list of paths.
-    Alignment files are expected to be .bam, .sam, or .sam.gz.
-
-    Parameters
-    ----------
-    paths
-        Input list of paths
-
-    Returns
-    -------
-        Output list of alignment files
-    """
-    alignments = []
-    suffixes = (".bam", ".sam", ".sam.gz")
-
-    for path in paths:
-        # break
-        if path.is_file() and any(path_endswith(path, suffix) for suffix in suffixes):
-            alignments.append(path)
-
-        elif path.is_dir():
-
-            files = [
-                p
-                for p in Path(path).glob("*")
-                if any(path_endswith(p, suffix) for suffix in suffixes)
-            ]
-
-            recursive = extract_alignment_files(files)
-            alignments.extend(recursive)
-
-    return alignments
-
-
-def extract_samples(
-    paths: list[Path],
-    prefix: str = "",
-    suffix: str = "",
-    long_name: bool = False,
-) -> dict:
-    """Extract all alignment files from a list of files.
-    Truncates the name of the files, controlled by prefix, suffix, and long_name
-
-    Parameters
-    ----------
-    paths
-        List of paths to be extracted
-    prefix
-        The prefix to be added to the name, by default ""
-    suffix
-        The suffix to be added to the name, by default ""
-    long_name
-        Whether or not to use the full name, by default False
-
-    Returns
-    -------
-        Dictionary with names as keys and files as values.
-    """
-
-    alignments = extract_alignment_files(paths)
-    samples = extract_names(
-        alignments,
-        prefix=prefix,
-        suffix=suffix,
-        long_name=long_name,
-    )
-
-    d_alignments = {}
-    for sample, path in zip(samples, alignments):
-        d_alignments[sample] = str(path)
-
-    return d_alignments
-
-
-def paths_to_strings(
-    d: dict,
-    ignore_keys: Optional[Iterable] = None,
-) -> dict:
-    """Convert all the paths in a dictionary to strings
-
-    Parameters
-    ----------
-    d
-        Input dict to be converted
-    ignore_keys
-        Ignore the following keys in the iterable, by default None
-
-    Returns
-    -------
-        Dictionary with strings instead of paths
-    """
-
-    if ignore_keys is None:
-        ignore_keys = []
-
-    d_out = {}
-    for key, val in d.items():
-        if val in ignore_keys:
-            continue
-        elif isinstance(val, list):
-            d_out[key] = list(map(str, val))
-        elif isinstance(val, tuple):
-            d_out[key] = tuple(map(str, val))
-        elif isinstance(val, dict):
-            d_out[key] = paths_to_strings(val)
-        elif isinstance(val, Path):
-            d_out[key] = str(val)
-        else:
-            d_out[key] = val
-    return d_out
-
-
 #%%
 
 
-def save_config_file(
-    config: dict,
-    config_file: Path,
-    overwrite_config: bool = False,
-) -> None:
-    """Save the config file.
-    Does not overwrite if file already exists, unless explicitly specified.
-
-    Parameters
-    ----------
-    config
-        Input dict
-    config_file
-        Save location
-
-    Raises
-    ------
-    typer.Abort
-        Do not overwrite automatically
-    """
-
-    if not overwrite_config:
-        if config_file.is_file():
-            s = "Config file already exists. Do you want to overwrite it?"
-            confirmed = typer.confirm(s)
-            if not confirmed:
-                typer.echo("Exiting")
-                raise typer.Abort()
-
-    with open(config_file, "w") as file:
-        yaml.dump(config, file, sort_keys=False)
-    typer.echo(f"{str(config_file)} was created")
-
-
 #%%
 
 
